/**
 * DevOps API
 * Use the DevOps APIs to create a DevOps project to group the pipelines,  add reference to target deployment environments, add artifacts to deploy,  and create deployment pipelines needed to deploy your software.
 * OpenAPI spec version: 20210630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { DevopsWaiter } from "./devops-waiter";
export declare enum DevopsApiKeys {
}
export declare class DevopsClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DevopsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DevopsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DevopsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DevopsWaiter;
    /**
     * Submit stage approval.
     * @param ApproveDeploymentRequest
     * @return ApproveDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ApproveDeployment.ts.html |here} to see how to use ApproveDeployment API.
     */
    approveDeployment(approveDeploymentRequest: requests.ApproveDeploymentRequest): Promise<responses.ApproveDeploymentResponse>;
    /**
     * Cancels a deployment resource by identifier.
     * @param CancelDeploymentRequest
     * @return CancelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/CancelDeployment.ts.html |here} to see how to use CancelDeployment API.
     */
    cancelDeployment(cancelDeploymentRequest: requests.CancelDeploymentRequest): Promise<responses.CancelDeploymentResponse>;
    /**
     * Moves a project resource from one compartment OCID to another.
     * @param ChangeProjectCompartmentRequest
     * @return ChangeProjectCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ChangeProjectCompartment.ts.html |here} to see how to use ChangeProjectCompartment API.
     */
    changeProjectCompartment(changeProjectCompartmentRequest: requests.ChangeProjectCompartmentRequest): Promise<responses.ChangeProjectCompartmentResponse>;
    /**
     * Creates a new deployment artifact.
     * @param CreateDeployArtifactRequest
     * @return CreateDeployArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/CreateDeployArtifact.ts.html |here} to see how to use CreateDeployArtifact API.
     */
    createDeployArtifact(createDeployArtifactRequest: requests.CreateDeployArtifactRequest): Promise<responses.CreateDeployArtifactResponse>;
    /**
     * Creates a new deployment environment.
     * @param CreateDeployEnvironmentRequest
     * @return CreateDeployEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/CreateDeployEnvironment.ts.html |here} to see how to use CreateDeployEnvironment API.
     */
    createDeployEnvironment(createDeployEnvironmentRequest: requests.CreateDeployEnvironmentRequest): Promise<responses.CreateDeployEnvironmentResponse>;
    /**
     * Creates a new deployment pipeline.
     * @param CreateDeployPipelineRequest
     * @return CreateDeployPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/CreateDeployPipeline.ts.html |here} to see how to use CreateDeployPipeline API.
     */
    createDeployPipeline(createDeployPipelineRequest: requests.CreateDeployPipelineRequest): Promise<responses.CreateDeployPipelineResponse>;
    /**
     * Creates a new deployment stage.
     * @param CreateDeployStageRequest
     * @return CreateDeployStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/CreateDeployStage.ts.html |here} to see how to use CreateDeployStage API.
     */
    createDeployStage(createDeployStageRequest: requests.CreateDeployStageRequest): Promise<responses.CreateDeployStageResponse>;
    /**
     * Creates a new deployment.
     * @param CreateDeploymentRequest
     * @return CreateDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/CreateDeployment.ts.html |here} to see how to use CreateDeployment API.
     */
    createDeployment(createDeploymentRequest: requests.CreateDeploymentRequest): Promise<responses.CreateDeploymentResponse>;
    /**
     * Creates a new project.
     * @param CreateProjectRequest
     * @return CreateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/CreateProject.ts.html |here} to see how to use CreateProject API.
     */
    createProject(createProjectRequest: requests.CreateProjectRequest): Promise<responses.CreateProjectResponse>;
    /**
     * Deletes a deployment artifact resource by identifier.
     * @param DeleteDeployArtifactRequest
     * @return DeleteDeployArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/DeleteDeployArtifact.ts.html |here} to see how to use DeleteDeployArtifact API.
     */
    deleteDeployArtifact(deleteDeployArtifactRequest: requests.DeleteDeployArtifactRequest): Promise<responses.DeleteDeployArtifactResponse>;
    /**
     * Deletes a deployment environment resource by identifier.
     * @param DeleteDeployEnvironmentRequest
     * @return DeleteDeployEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/DeleteDeployEnvironment.ts.html |here} to see how to use DeleteDeployEnvironment API.
     */
    deleteDeployEnvironment(deleteDeployEnvironmentRequest: requests.DeleteDeployEnvironmentRequest): Promise<responses.DeleteDeployEnvironmentResponse>;
    /**
     * Deletes a deployment pipeline resource by identifier.
     * @param DeleteDeployPipelineRequest
     * @return DeleteDeployPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/DeleteDeployPipeline.ts.html |here} to see how to use DeleteDeployPipeline API.
     */
    deleteDeployPipeline(deleteDeployPipelineRequest: requests.DeleteDeployPipelineRequest): Promise<responses.DeleteDeployPipelineResponse>;
    /**
     * Deletes a deployment stage resource by identifier.
     * @param DeleteDeployStageRequest
     * @return DeleteDeployStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/DeleteDeployStage.ts.html |here} to see how to use DeleteDeployStage API.
     */
    deleteDeployStage(deleteDeployStageRequest: requests.DeleteDeployStageRequest): Promise<responses.DeleteDeployStageResponse>;
    /**
     * Deletes a project resource by identifier
     * @param DeleteProjectRequest
     * @return DeleteProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/DeleteProject.ts.html |here} to see how to use DeleteProject API.
     */
    deleteProject(deleteProjectRequest: requests.DeleteProjectRequest): Promise<responses.DeleteProjectResponse>;
    /**
     * Retrieves a deployment artifact by identifier.
     * @param GetDeployArtifactRequest
     * @return GetDeployArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/GetDeployArtifact.ts.html |here} to see how to use GetDeployArtifact API.
     */
    getDeployArtifact(getDeployArtifactRequest: requests.GetDeployArtifactRequest): Promise<responses.GetDeployArtifactResponse>;
    /**
     * Retrieves a deployment environment by identifier.
     * @param GetDeployEnvironmentRequest
     * @return GetDeployEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/GetDeployEnvironment.ts.html |here} to see how to use GetDeployEnvironment API.
     */
    getDeployEnvironment(getDeployEnvironmentRequest: requests.GetDeployEnvironmentRequest): Promise<responses.GetDeployEnvironmentResponse>;
    /**
     * Retrieves a deployment pipeline by identifier.
     * @param GetDeployPipelineRequest
     * @return GetDeployPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/GetDeployPipeline.ts.html |here} to see how to use GetDeployPipeline API.
     */
    getDeployPipeline(getDeployPipelineRequest: requests.GetDeployPipelineRequest): Promise<responses.GetDeployPipelineResponse>;
    /**
     * Retrieves a deployment stage by identifier.
     * @param GetDeployStageRequest
     * @return GetDeployStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/GetDeployStage.ts.html |here} to see how to use GetDeployStage API.
     */
    getDeployStage(getDeployStageRequest: requests.GetDeployStageRequest): Promise<responses.GetDeployStageResponse>;
    /**
     * Retrieves a deployment by identifier.
     * @param GetDeploymentRequest
     * @return GetDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/GetDeployment.ts.html |here} to see how to use GetDeployment API.
     */
    getDeployment(getDeploymentRequest: requests.GetDeploymentRequest): Promise<responses.GetDeploymentResponse>;
    /**
     * Retrieves a project by identifier.
     * @param GetProjectRequest
     * @return GetProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/GetProject.ts.html |here} to see how to use GetProject API.
     */
    getProject(getProjectRequest: requests.GetProjectRequest): Promise<responses.GetProjectResponse>;
    /**
     * Retrieves the status of the work request with the given ID.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of deployment artifacts.
     * @param ListDeployArtifactsRequest
     * @return ListDeployArtifactsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ListDeployArtifacts.ts.html |here} to see how to use ListDeployArtifacts API.
     */
    listDeployArtifacts(listDeployArtifactsRequest: requests.ListDeployArtifactsRequest): Promise<responses.ListDeployArtifactsResponse>;
    /**
     * Returns a list of deployment environments.
     * @param ListDeployEnvironmentsRequest
     * @return ListDeployEnvironmentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ListDeployEnvironments.ts.html |here} to see how to use ListDeployEnvironments API.
     */
    listDeployEnvironments(listDeployEnvironmentsRequest: requests.ListDeployEnvironmentsRequest): Promise<responses.ListDeployEnvironmentsResponse>;
    /**
     * Returns a list of deployment pipelines.
     * @param ListDeployPipelinesRequest
     * @return ListDeployPipelinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ListDeployPipelines.ts.html |here} to see how to use ListDeployPipelines API.
     */
    listDeployPipelines(listDeployPipelinesRequest: requests.ListDeployPipelinesRequest): Promise<responses.ListDeployPipelinesResponse>;
    /**
     * Retrieves a list of deployment stages.
     * @param ListDeployStagesRequest
     * @return ListDeployStagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ListDeployStages.ts.html |here} to see how to use ListDeployStages API.
     */
    listDeployStages(listDeployStagesRequest: requests.ListDeployStagesRequest): Promise<responses.ListDeployStagesResponse>;
    /**
     * Returns a list of deployments.
     * @param ListDeploymentsRequest
     * @return ListDeploymentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ListDeployments.ts.html |here} to see how to use ListDeployments API.
     */
    listDeployments(listDeploymentsRequest: requests.ListDeploymentsRequest): Promise<responses.ListDeploymentsResponse>;
    /**
     * Returns a list of projects.
     * @param ListProjectsRequest
     * @return ListProjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ListProjects.ts.html |here} to see how to use ListProjects API.
     */
    listProjects(listProjectsRequest: requests.ListProjectsRequest): Promise<responses.ListProjectsResponse>;
    /**
     * Returns a list of errors for a given work request.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a list of logs for a given work request.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Updates the deployment artifact.
     * @param UpdateDeployArtifactRequest
     * @return UpdateDeployArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/UpdateDeployArtifact.ts.html |here} to see how to use UpdateDeployArtifact API.
     */
    updateDeployArtifact(updateDeployArtifactRequest: requests.UpdateDeployArtifactRequest): Promise<responses.UpdateDeployArtifactResponse>;
    /**
     * Updates the deployment environment.
     * @param UpdateDeployEnvironmentRequest
     * @return UpdateDeployEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/UpdateDeployEnvironment.ts.html |here} to see how to use UpdateDeployEnvironment API.
     */
    updateDeployEnvironment(updateDeployEnvironmentRequest: requests.UpdateDeployEnvironmentRequest): Promise<responses.UpdateDeployEnvironmentResponse>;
    /**
     * Updates the deployment pipeline.
     * @param UpdateDeployPipelineRequest
     * @return UpdateDeployPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/UpdateDeployPipeline.ts.html |here} to see how to use UpdateDeployPipeline API.
     */
    updateDeployPipeline(updateDeployPipelineRequest: requests.UpdateDeployPipelineRequest): Promise<responses.UpdateDeployPipelineResponse>;
    /**
     * Updates the deployment stage.
     * @param UpdateDeployStageRequest
     * @return UpdateDeployStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/UpdateDeployStage.ts.html |here} to see how to use UpdateDeployStage API.
     */
    updateDeployStage(updateDeployStageRequest: requests.UpdateDeployStageRequest): Promise<responses.UpdateDeployStageResponse>;
    /**
     * Updates the deployment.
     * @param UpdateDeploymentRequest
     * @return UpdateDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/UpdateDeployment.ts.html |here} to see how to use UpdateDeployment API.
     */
    updateDeployment(updateDeploymentRequest: requests.UpdateDeploymentRequest): Promise<responses.UpdateDeploymentResponse>;
    /**
     * Updates the project.
     * @param UpdateProjectRequest
     * @return UpdateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/devops/UpdateProject.ts.html |here} to see how to use UpdateProject API.
     */
    updateProject(updateProjectRequest: requests.UpdateProjectRequest): Promise<responses.UpdateProjectResponse>;
}
