/**
 * Scanning API
 * Use the Vulnerability Scanning Service (VSS) APIs to manage scan recipes, targets, and reports.
 * OpenAPI spec version: 20210215
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { VulnerabilityScanningWaiter } from "./vulnerabilityscanning-waiter";
export declare enum VulnerabilityScanningApiKeys {
}
export declare class VulnerabilityScanningClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": VulnerabilityScanningWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new VulnerabilityScanningWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): VulnerabilityScanningWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): VulnerabilityScanningWaiter;
    /**
     * Moves a ContainerScanRecipe into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * @param ChangeContainerScanRecipeCompartmentRequest
     * @return ChangeContainerScanRecipeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ChangeContainerScanRecipeCompartment.ts.html |here} to see how to use ChangeContainerScanRecipeCompartment API.
     */
    changeContainerScanRecipeCompartment(changeContainerScanRecipeCompartmentRequest: requests.ChangeContainerScanRecipeCompartmentRequest): Promise<responses.ChangeContainerScanRecipeCompartmentResponse>;
    /**
     * Moves a ContainerScanResult into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * @param ChangeContainerScanResultCompartmentRequest
     * @return ChangeContainerScanResultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ChangeContainerScanResultCompartment.ts.html |here} to see how to use ChangeContainerScanResultCompartment API.
     */
    changeContainerScanResultCompartment(changeContainerScanResultCompartmentRequest: requests.ChangeContainerScanResultCompartmentRequest): Promise<responses.ChangeContainerScanResultCompartmentResponse>;
    /**
     * Moves a ContainerScanTarget into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * @param ChangeContainerScanTargetCompartmentRequest
     * @return ChangeContainerScanTargetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ChangeContainerScanTargetCompartment.ts.html |here} to see how to use ChangeContainerScanTargetCompartment API.
     */
    changeContainerScanTargetCompartment(changeContainerScanTargetCompartmentRequest: requests.ChangeContainerScanTargetCompartmentRequest): Promise<responses.ChangeContainerScanTargetCompartmentResponse>;
    /**
     * Moves a HostAgentScanResult into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * @param ChangeHostAgentScanResultCompartmentRequest
     * @return ChangeHostAgentScanResultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ChangeHostAgentScanResultCompartment.ts.html |here} to see how to use ChangeHostAgentScanResultCompartment API.
     */
    changeHostAgentScanResultCompartment(changeHostAgentScanResultCompartmentRequest: requests.ChangeHostAgentScanResultCompartmentRequest): Promise<responses.ChangeHostAgentScanResultCompartmentResponse>;
    /**
     * Moves a HostCisBenchmarkScanResult into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * @param ChangeHostCisBenchmarkScanResultCompartmentRequest
     * @return ChangeHostCisBenchmarkScanResultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ChangeHostCisBenchmarkScanResultCompartment.ts.html |here} to see how to use ChangeHostCisBenchmarkScanResultCompartment API.
     */
    changeHostCisBenchmarkScanResultCompartment(changeHostCisBenchmarkScanResultCompartmentRequest: requests.ChangeHostCisBenchmarkScanResultCompartmentRequest): Promise<responses.ChangeHostCisBenchmarkScanResultCompartmentResponse>;
    /**
     * Moves a HostEndpointProtectionScanResult into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * @param ChangeHostEndpointProtectionScanResultCompartmentRequest
     * @return ChangeHostEndpointProtectionScanResultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ChangeHostEndpointProtectionScanResultCompartment.ts.html |here} to see how to use ChangeHostEndpointProtectionScanResultCompartment API.
     */
    changeHostEndpointProtectionScanResultCompartment(changeHostEndpointProtectionScanResultCompartmentRequest: requests.ChangeHostEndpointProtectionScanResultCompartmentRequest): Promise<responses.ChangeHostEndpointProtectionScanResultCompartmentResponse>;
    /**
     * Moves a HostPortScanResult into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * @param ChangeHostPortScanResultCompartmentRequest
     * @return ChangeHostPortScanResultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ChangeHostPortScanResultCompartment.ts.html |here} to see how to use ChangeHostPortScanResultCompartment API.
     */
    changeHostPortScanResultCompartment(changeHostPortScanResultCompartmentRequest: requests.ChangeHostPortScanResultCompartmentRequest): Promise<responses.ChangeHostPortScanResultCompartmentResponse>;
    /**
     * Moves a HostScanRecipe into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * @param ChangeHostScanRecipeCompartmentRequest
     * @return ChangeHostScanRecipeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ChangeHostScanRecipeCompartment.ts.html |here} to see how to use ChangeHostScanRecipeCompartment API.
     */
    changeHostScanRecipeCompartment(changeHostScanRecipeCompartmentRequest: requests.ChangeHostScanRecipeCompartmentRequest): Promise<responses.ChangeHostScanRecipeCompartmentResponse>;
    /**
     * Moves a HostScanTarget into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * @param ChangeHostScanTargetCompartmentRequest
     * @return ChangeHostScanTargetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ChangeHostScanTargetCompartment.ts.html |here} to see how to use ChangeHostScanTargetCompartment API.
     */
    changeHostScanTargetCompartment(changeHostScanTargetCompartmentRequest: requests.ChangeHostScanTargetCompartmentRequest): Promise<responses.ChangeHostScanTargetCompartmentResponse>;
    /**
     * Creates a new ContainerScanRecipe
     *
     * @param CreateContainerScanRecipeRequest
     * @return CreateContainerScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/CreateContainerScanRecipe.ts.html |here} to see how to use CreateContainerScanRecipe API.
     */
    createContainerScanRecipe(createContainerScanRecipeRequest: requests.CreateContainerScanRecipeRequest): Promise<responses.CreateContainerScanRecipeResponse>;
    /**
     * Creates a new ContainerScanTarget
     *
     * @param CreateContainerScanTargetRequest
     * @return CreateContainerScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/CreateContainerScanTarget.ts.html |here} to see how to use CreateContainerScanTarget API.
     */
    createContainerScanTarget(createContainerScanTargetRequest: requests.CreateContainerScanTargetRequest): Promise<responses.CreateContainerScanTargetResponse>;
    /**
     * Creates a new HostScanRecipe. A recipe determines the types of security issues that you want scanned, and how often to scan.
     *
     * @param CreateHostScanRecipeRequest
     * @return CreateHostScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/CreateHostScanRecipe.ts.html |here} to see how to use CreateHostScanRecipe API.
     */
    createHostScanRecipe(createHostScanRecipeRequest: requests.CreateHostScanRecipeRequest): Promise<responses.CreateHostScanRecipeResponse>;
    /**
     * Creates a new HostScanTarget. A host scan target is a collection of compute instances that you want routinely scanned for security vulnerabilities.
     *
     * @param CreateHostScanTargetRequest
     * @return CreateHostScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/CreateHostScanTarget.ts.html |here} to see how to use CreateHostScanTarget API.
     */
    createHostScanTarget(createHostScanTargetRequest: requests.CreateHostScanTargetRequest): Promise<responses.CreateHostScanTargetResponse>;
    /**
     * Deletes the ContainerScanRecipe identified by the id
     *
     * @param DeleteContainerScanRecipeRequest
     * @return DeleteContainerScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/DeleteContainerScanRecipe.ts.html |here} to see how to use DeleteContainerScanRecipe API.
     */
    deleteContainerScanRecipe(deleteContainerScanRecipeRequest: requests.DeleteContainerScanRecipeRequest): Promise<responses.DeleteContainerScanRecipeResponse>;
    /**
     * Deletes the ContainerScanResult identified by the id
     *
     * @param DeleteContainerScanResultRequest
     * @return DeleteContainerScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/DeleteContainerScanResult.ts.html |here} to see how to use DeleteContainerScanResult API.
     */
    deleteContainerScanResult(deleteContainerScanResultRequest: requests.DeleteContainerScanResultRequest): Promise<responses.DeleteContainerScanResultResponse>;
    /**
     * Deletes the ContainerScanTarget identified by the id
     *
     * @param DeleteContainerScanTargetRequest
     * @return DeleteContainerScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/DeleteContainerScanTarget.ts.html |here} to see how to use DeleteContainerScanTarget API.
     */
    deleteContainerScanTarget(deleteContainerScanTargetRequest: requests.DeleteContainerScanTargetRequest): Promise<responses.DeleteContainerScanTargetResponse>;
    /**
     * Removes the HostAgentScanResult identified by the host agent scan ID.
     *
     * @param DeleteHostAgentScanResultRequest
     * @return DeleteHostAgentScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/DeleteHostAgentScanResult.ts.html |here} to see how to use DeleteHostAgentScanResult API.
     */
    deleteHostAgentScanResult(deleteHostAgentScanResultRequest: requests.DeleteHostAgentScanResultRequest): Promise<responses.DeleteHostAgentScanResultResponse>;
    /**
     * Deletes the HostCisBenchmarkScanResult identified by the id
     *
     * @param DeleteHostCisBenchmarkScanResultRequest
     * @return DeleteHostCisBenchmarkScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/DeleteHostCisBenchmarkScanResult.ts.html |here} to see how to use DeleteHostCisBenchmarkScanResult API.
     */
    deleteHostCisBenchmarkScanResult(deleteHostCisBenchmarkScanResultRequest: requests.DeleteHostCisBenchmarkScanResultRequest): Promise<responses.DeleteHostCisBenchmarkScanResultResponse>;
    /**
     * Deletes the HostEndpointProtectionScanResult identified by the id
     *
     * @param DeleteHostEndpointProtectionScanResultRequest
     * @return DeleteHostEndpointProtectionScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/DeleteHostEndpointProtectionScanResult.ts.html |here} to see how to use DeleteHostEndpointProtectionScanResult API.
     */
    deleteHostEndpointProtectionScanResult(deleteHostEndpointProtectionScanResultRequest: requests.DeleteHostEndpointProtectionScanResultRequest): Promise<responses.DeleteHostEndpointProtectionScanResultResponse>;
    /**
     * Removes the HostPortScanResult identified by the host port scan ID.
     *
     * @param DeleteHostPortScanResultRequest
     * @return DeleteHostPortScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/DeleteHostPortScanResult.ts.html |here} to see how to use DeleteHostPortScanResult API.
     */
    deleteHostPortScanResult(deleteHostPortScanResultRequest: requests.DeleteHostPortScanResultRequest): Promise<responses.DeleteHostPortScanResultResponse>;
    /**
     * Removes the HostScanRecipe identified by the recipe ID.
     *
     * @param DeleteHostScanRecipeRequest
     * @return DeleteHostScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/DeleteHostScanRecipe.ts.html |here} to see how to use DeleteHostScanRecipe API.
     */
    deleteHostScanRecipe(deleteHostScanRecipeRequest: requests.DeleteHostScanRecipeRequest): Promise<responses.DeleteHostScanRecipeResponse>;
    /**
     * Removes the HostScanTarget identified by the target ID.
     *
     * @param DeleteHostScanTargetRequest
     * @return DeleteHostScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/DeleteHostScanTarget.ts.html |here} to see how to use DeleteHostScanTarget API.
     */
    deleteHostScanTarget(deleteHostScanTargetRequest: requests.DeleteHostScanTargetRequest): Promise<responses.DeleteHostScanTargetResponse>;
    /**
     * Exports a list of HostAgentScanResultSummary objects within a compartment and during a specified time range in CSV format. You can filter the results by problem severity.
     *
     * @param ExportHostAgentScanResultCsvRequest
     * @return ExportHostAgentScanResultCsvResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ExportHostAgentScanResultCsv.ts.html |here} to see how to use ExportHostAgentScanResultCsv API.
     */
    exportHostAgentScanResultCsv(exportHostAgentScanResultCsvRequest: requests.ExportHostAgentScanResultCsvRequest): Promise<responses.ExportHostAgentScanResultCsvResponse>;
    /**
     * Exports a list of HostVulnerabilitySummary objects in a compartment in CSV format.
     *
     * @param ExportHostVulnerabilityCsvRequest
     * @return ExportHostVulnerabilityCsvResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ExportHostVulnerabilityCsv.ts.html |here} to see how to use ExportHostVulnerabilityCsv API.
     */
    exportHostVulnerabilityCsv(exportHostVulnerabilityCsvRequest: requests.ExportHostVulnerabilityCsvRequest): Promise<responses.ExportHostVulnerabilityCsvResponse>;
    /**
     * Gets a ContainerScanRecipe by identifier
     *
     * @param GetContainerScanRecipeRequest
     * @return GetContainerScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetContainerScanRecipe.ts.html |here} to see how to use GetContainerScanRecipe API.
     */
    getContainerScanRecipe(getContainerScanRecipeRequest: requests.GetContainerScanRecipeRequest): Promise<responses.GetContainerScanRecipeResponse>;
    /**
     * Returns a ContainerScanResult of the given container scan ID.
     *
     * @param GetContainerScanResultRequest
     * @return GetContainerScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetContainerScanResult.ts.html |here} to see how to use GetContainerScanResult API.
     */
    getContainerScanResult(getContainerScanResultRequest: requests.GetContainerScanResultRequest): Promise<responses.GetContainerScanResultResponse>;
    /**
     * Gets a ContainerScanTarget by identifier
     *
     * @param GetContainerScanTargetRequest
     * @return GetContainerScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetContainerScanTarget.ts.html |here} to see how to use GetContainerScanTarget API.
     */
    getContainerScanTarget(getContainerScanTargetRequest: requests.GetContainerScanTargetRequest): Promise<responses.GetContainerScanTargetResponse>;
    /**
     * Retrieves a HostAgentScanResult identified by the host agent scan ID. The result includes a list of problems detected in a specific compute instance.
     *
     * @param GetHostAgentScanResultRequest
     * @return GetHostAgentScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetHostAgentScanResult.ts.html |here} to see how to use GetHostAgentScanResult API.
     */
    getHostAgentScanResult(getHostAgentScanResultRequest: requests.GetHostAgentScanResultRequest): Promise<responses.GetHostAgentScanResultResponse>;
    /**
     * Returns HostCisBenchmarkScanResults for the given host CIS (Center for Internet Security) benchmark scan result ID.
     *
     * @param GetHostCisBenchmarkScanResultRequest
     * @return GetHostCisBenchmarkScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetHostCisBenchmarkScanResult.ts.html |here} to see how to use GetHostCisBenchmarkScanResult API.
     */
    getHostCisBenchmarkScanResult(getHostCisBenchmarkScanResultRequest: requests.GetHostCisBenchmarkScanResultRequest): Promise<responses.GetHostCisBenchmarkScanResultResponse>;
    /**
     * Returns HostEndpointProtectionScanResults for the given host endpoint protection scan result ID.
     *
     * @param GetHostEndpointProtectionScanResultRequest
     * @return GetHostEndpointProtectionScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetHostEndpointProtectionScanResult.ts.html |here} to see how to use GetHostEndpointProtectionScanResult API.
     */
    getHostEndpointProtectionScanResult(getHostEndpointProtectionScanResultRequest: requests.GetHostEndpointProtectionScanResultRequest): Promise<responses.GetHostEndpointProtectionScanResultResponse>;
    /**
     * Retrieves a HostPortScanResult identified by the host port scan ID. The result includes a list of open ports that were detected in a specific compute instance.
     *
     * @param GetHostPortScanResultRequest
     * @return GetHostPortScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetHostPortScanResult.ts.html |here} to see how to use GetHostPortScanResult API.
     */
    getHostPortScanResult(getHostPortScanResultRequest: requests.GetHostPortScanResultRequest): Promise<responses.GetHostPortScanResultResponse>;
    /**
     * Retrieves a HostScanRecipe identified by the recipe ID. A recipe determines the types of security issues that you want scanned, and how often to scan.
     *
     * @param GetHostScanRecipeRequest
     * @return GetHostScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetHostScanRecipe.ts.html |here} to see how to use GetHostScanRecipe API.
     */
    getHostScanRecipe(getHostScanRecipeRequest: requests.GetHostScanRecipeRequest): Promise<responses.GetHostScanRecipeResponse>;
    /**
     * Retrieves a HostScanTarget identified by the target ID. A host scan target is a collection of compute instances that you want routinely scanned for security vulnerabilities.
     *
     * @param GetHostScanTargetRequest
     * @return GetHostScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetHostScanTarget.ts.html |here} to see how to use GetHostScanTarget API.
     */
    getHostScanTarget(getHostScanTargetRequest: requests.GetHostScanTargetRequest): Promise<responses.GetHostScanTargetResponse>;
    /**
     * Retrieves a HostVulnerability identified by the host vulnerability ID. A host vulnerability describes a security issue that was detected in scans of one or more compute instances. Common Vulnerabilities and Exposures (CVE) numbers identify security vulnerabilities for operating systems and other software, including Critical Patch Updates and Security Alert advisories.
     *
     * @param GetHostVulnerabilityRequest
     * @return GetHostVulnerabilityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetHostVulnerability.ts.html |here} to see how to use GetHostVulnerability API.
     */
    getHostVulnerability(getHostVulnerabilityRequest: requests.GetHostVulnerabilityRequest): Promise<responses.GetHostVulnerabilityResponse>;
    /**
     * Gets the status of the work request with the given ID.
     *
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of ContainerScanRecipeSummaries
     *
     * @param ListContainerScanRecipesRequest
     * @return ListContainerScanRecipesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListContainerScanRecipes.ts.html |here} to see how to use ListContainerScanRecipes API.
     */
    listContainerScanRecipes(listContainerScanRecipesRequest: requests.ListContainerScanRecipesRequest): Promise<responses.ListContainerScanRecipesResponse>;
    /**
     * Returns a collection of ContainerScanResultSummary objects
     *
     * @param ListContainerScanResultsRequest
     * @return ListContainerScanResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListContainerScanResults.ts.html |here} to see how to use ListContainerScanResults API.
     */
    listContainerScanResults(listContainerScanResultsRequest: requests.ListContainerScanResultsRequest): Promise<responses.ListContainerScanResultsResponse>;
    /**
     * Returns a list of ContainerScanTargetSummaries
     *
     * @param ListContainerScanTargetsRequest
     * @return ListContainerScanTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListContainerScanTargets.ts.html |here} to see how to use ListContainerScanTargets API.
     */
    listContainerScanTargets(listContainerScanTargetsRequest: requests.ListContainerScanTargetsRequest): Promise<responses.ListContainerScanTargetsResponse>;
    /**
     * Retrieves a list of HostAgentScanResultSummary objects in a compartment. You can filter and sort the results by problem severity and time. An agent scan result includes a list of problems detected in a specific compute instance.
     *
     * @param ListHostAgentScanResultsRequest
     * @return ListHostAgentScanResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListHostAgentScanResults.ts.html |here} to see how to use ListHostAgentScanResults API.
     */
    listHostAgentScanResults(listHostAgentScanResultsRequest: requests.ListHostAgentScanResultsRequest): Promise<responses.ListHostAgentScanResultsResponse>;
    /**
     * Returns a collection of HostCisBenchmarkScanResultSummary objects
     *
     * @param ListHostCisBenchmarkScanResultsRequest
     * @return ListHostCisBenchmarkScanResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListHostCisBenchmarkScanResults.ts.html |here} to see how to use ListHostCisBenchmarkScanResults API.
     */
    listHostCisBenchmarkScanResults(listHostCisBenchmarkScanResultsRequest: requests.ListHostCisBenchmarkScanResultsRequest): Promise<responses.ListHostCisBenchmarkScanResultsResponse>;
    /**
     * Returns a collection of HostEndpointProtectionScanResultSummary objects
     *
     * @param ListHostEndpointProtectionScanResultsRequest
     * @return ListHostEndpointProtectionScanResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListHostEndpointProtectionScanResults.ts.html |here} to see how to use ListHostEndpointProtectionScanResults API.
     */
    listHostEndpointProtectionScanResults(listHostEndpointProtectionScanResultsRequest: requests.ListHostEndpointProtectionScanResultsRequest): Promise<responses.ListHostEndpointProtectionScanResultsResponse>;
    /**
     * Retrieves a list of HostPortScanResultSummary objects in a compartment. You can filter and sort the results by problem severity and time. A port scan result includes a list of open ports that were detected in a specific compute instance.
     *
     * @param ListHostPortScanResultsRequest
     * @return ListHostPortScanResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListHostPortScanResults.ts.html |here} to see how to use ListHostPortScanResults API.
     */
    listHostPortScanResults(listHostPortScanResultsRequest: requests.ListHostPortScanResultsRequest): Promise<responses.ListHostPortScanResultsResponse>;
    /**
     * Retrieves a list of HostScanRecipeSummary objects in a compartment. A recipe determines the types of security issues that you want scanned, and how often to scan.
     *
     * @param ListHostScanRecipesRequest
     * @return ListHostScanRecipesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListHostScanRecipes.ts.html |here} to see how to use ListHostScanRecipes API.
     */
    listHostScanRecipes(listHostScanRecipesRequest: requests.ListHostScanRecipesRequest): Promise<responses.ListHostScanRecipesResponse>;
    /**
     * Retrieves a list of HostScanTargetSummary objects in a compartment. A host scan target is a collection of compute instances that you want routinely scanned for security vulnerabilities.
     *
     * @param ListHostScanTargetsRequest
     * @return ListHostScanTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListHostScanTargets.ts.html |here} to see how to use ListHostScanTargets API.
     */
    listHostScanTargets(listHostScanTargetsRequest: requests.ListHostScanTargetsRequest): Promise<responses.ListHostScanTargetsResponse>;
    /**
     * Retrieves a list of HostVulnerabilitySummary objects in a compartment. You can filter and sort the vulnerabilities by problem severity and time. A host vulnerability describes a security issue that was detected in scans of one or more compute instances.
     *
     * @param ListHostVulnerabilitiesRequest
     * @return ListHostVulnerabilitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListHostVulnerabilities.ts.html |here} to see how to use ListHostVulnerabilities API.
     */
    listHostVulnerabilities(listHostVulnerabilitiesRequest: requests.ListHostVulnerabilitiesRequest): Promise<responses.ListHostVulnerabilitiesResponse>;
    /**
     * Retrieves a list of HostVulnerabilityImpactedHostSummary objects for a specific host vulnerability ID. An impacted host summary identifies a compute instance on which the specified vulnerability was detected.
     *
     * @param ListHostVulnerabilityImpactedHostsRequest
     * @return ListHostVulnerabilityImpactedHostsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListHostVulnerabilityImpactedHosts.ts.html |here} to see how to use ListHostVulnerabilityImpactedHosts API.
     */
    listHostVulnerabilityImpactedHosts(listHostVulnerabilityImpactedHostsRequest: requests.ListHostVulnerabilityImpactedHostsRequest): Promise<responses.ListHostVulnerabilityImpactedHostsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Updates the ContainerScanRecipe identified by the id
     *
     * @param UpdateContainerScanRecipeRequest
     * @return UpdateContainerScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/UpdateContainerScanRecipe.ts.html |here} to see how to use UpdateContainerScanRecipe API.
     */
    updateContainerScanRecipe(updateContainerScanRecipeRequest: requests.UpdateContainerScanRecipeRequest): Promise<responses.UpdateContainerScanRecipeResponse>;
    /**
     * Updates the ContainerScanTarget identified by the id
     *
     * @param UpdateContainerScanTargetRequest
     * @return UpdateContainerScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/UpdateContainerScanTarget.ts.html |here} to see how to use UpdateContainerScanTarget API.
     */
    updateContainerScanTarget(updateContainerScanTargetRequest: requests.UpdateContainerScanTargetRequest): Promise<responses.UpdateContainerScanTargetResponse>;
    /**
     * Updates the HostScanRecipe identified by the recipe ID. A recipe determines the types of security issues that you want scanned, and how often to scan.
     *
     * @param UpdateHostScanRecipeRequest
     * @return UpdateHostScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/UpdateHostScanRecipe.ts.html |here} to see how to use UpdateHostScanRecipe API.
     */
    updateHostScanRecipe(updateHostScanRecipeRequest: requests.UpdateHostScanRecipeRequest): Promise<responses.UpdateHostScanRecipeResponse>;
    /**
     * Updates the HostScanTarget identified by the target ID. A host scan target is a collection of compute instances that you want routinely scanned for security vulnerabilities.
     *
     * @param UpdateHostScanTargetRequest
     * @return UpdateHostScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.22.0/vulnerabilityscanning/UpdateHostScanTarget.ts.html |here} to see how to use UpdateHostScanTarget API.
     */
    updateHostScanTarget(updateHostScanTargetRequest: requests.UpdateHostScanTargetRequest): Promise<responses.UpdateHostScanTargetResponse>;
}
